@@ -1,27 +1,14 @@
 /*
-   Copyright (C) 2015-2019 Montel Laurent <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef RICHTEXTCOMPOSERNG_H
-#define RICHTEXTCOMPOSERNG_H
+#ifndef MESSAGECOMPOSER_RICHTEXTCOMPOSERNG_H
+#define MESSAGECOMPOSER_RICHTEXTCOMPOSERNG_H
 
 #include "messagecomposer_export.h"
-#include <kpimtextedit/richtextcomposer.h>
+#include <KPIMTextEdit/RichTextComposer>
 #include <MessageComposer/PluginEditorConvertTextInterface>
 #include <KIdentityManagement/Signature>
 
@@ -33,6 +20,10 @@ namespace MessageComposer {
 class TextPart;
 class RichTextComposerSignatures;
 class RichTextComposerNgPrivate;
+/**
+ * @brief The RichTextComposerNg class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class MESSAGECOMPOSER_EXPORT RichTextComposerNg : public KPIMTextEdit::RichTextComposer
 {
     Q_OBJECT
@@ -54,9 +45,11 @@ public:
 
     Q_REQUIRED_RESULT virtual MessageComposer::PluginEditorConvertTextInterface::ConvertTextStatus convertPlainText(MessageComposer::TextPart *textPart);
 
+protected:
+    bool processModifyText(QKeyEvent *event) override;
+
 private:
-    bool processAutoCorrection(QKeyEvent *event) override;
     RichTextComposerNgPrivate *const d;
 };
 }
-#endif // RICHTEXTCOMPOSERNG_H
+#endif
