@@ -1,20 +1,6 @@
-/* Copyright 2009 Thomas McGuire <mcguire@kde.org>
+/* SPDX-FileCopyrightText: 2009 Thomas McGuire <mcguire@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 #include "stringutiltest.h"
 
@@ -411,7 +397,6 @@ void StringUtilTest::test_parseMailToWithUtf8Encoded()
             QCOMPARE(data.at(i).second, QString::fromUtf8("Mi\u0142osz Vo <raco.cki@foo.com>"));
         }
     }
-
 }
 
 void StringUtilTest::test_parseMailToWithUtf8QuotedEncoded()
@@ -425,7 +410,6 @@ void StringUtilTest::test_parseMailToWithUtf8QuotedEncoded()
             QCOMPARE(data.at(i).second, QString::fromUtf8("foo Cen <bla.cete@kde.com>, Kile Debut <kile.debut@foo.com"));
         }
     }
-
 }
 
 void StringUtilTest::test_parseMailToBug366981()
