@@ -1,9 +1,8 @@
-﻿/*******************************************************************************
+/*******************************************************************************
 **
 ** Filename   : util
 ** Created on : 03 April, 2005
-** Copyright  : (c) 2005 Till Adam
-** Email      : <adam@kde.org>
+** SPDX-FileCopyrightText : 2005 Till Adam <adam@kde.org>
 **
 *******************************************************************************/
 
@@ -38,22 +37,21 @@
 
 #include "messageviewer/messageviewerutil.h"
 #include "messageviewerutil_p.h"
-#include "kpimtextedit/texttospeech.h"
+#include <KPIMTextEdit/TextToSpeech>
 #include <MimeTreeParser/NodeHelper>
 #include "messageviewer_debug.h"
 #include "MessageCore/MessageCoreSettings"
 #include "MessageCore/NodeHelper"
 #include "MessageCore/StringUtil"
-#include <kio_version.h>
 
-#include "PimCommon/RenameFileDialog"
+#include <PimCommon/RenameFileDialog>
 
 #include <Gravatar/GravatarCache>
 #include <gravatar/gravatarsettings.h>
 
 #include <AkonadiCore/item.h>
 
-#include <kmbox/mbox.h>
+#include <KMbox/MBox>
 
 #include <KMime/Message>
 #include <KFileWidget>
@@ -137,9 +135,11 @@ bool Util::containsExternalReferences(const QString &str, const QString &extraHe
             }
         }
         if (!newStringImg.isEmpty()) {
-            const bool containsReg2 = newStringImg.contains(QRegularExpression(QStringLiteral("<img.*src=\"https?:/.*\".*>"), QRegularExpression::CaseInsensitiveOption), &rmatch);
+            static QRegularExpression image1RegularExpression = QRegularExpression(QStringLiteral("<img.*src=\"https?:/.*\".*>"), QRegularExpression::CaseInsensitiveOption);
+            const bool containsReg2 = newStringImg.contains(image1RegularExpression, &rmatch);
             if (!containsReg2) {
-                const bool containsReg = newStringImg.contains(QRegularExpression(QStringLiteral("<img.*src=https?:/.*>"), QRegularExpression::CaseInsensitiveOption), &rmatch);
+                static QRegularExpression image2RegularExpression = QRegularExpression(QStringLiteral("<img.*src=https?:/.*>"), QRegularExpression::CaseInsensitiveOption);
+                const bool containsReg = newStringImg.contains(image2RegularExpression, &rmatch);
                 return containsReg;
             } else {
                 return true;
@@ -155,11 +155,7 @@ bool Util::checkOverwrite(const QUrl &url, QWidget *w)
     if (url.isLocalFile()) {
         fileExists = QFile::exists(url.toLocalFile());
     } else {
-#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
-        auto job = KIO::stat(url, KIO::StatJob::DestinationSide, 0, KIO::JobFlag::DefaultFlags);
-#else
         auto job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatBasic);
-#endif
         KJobWidgets::setWindow(job, w);
         fileExists = job->exec();
     }
@@ -321,11 +317,7 @@ bool Util::saveContents(QWidget *parent, const KMime::Content::List &contents, Q
                 if (curUrl.isLocalFile()) {
                     fileExists = QFile::exists(curUrl.toLocalFile());
                 } else {
-#if KIO_VERSION < QT_VERSION_CHECK(5, 69, 0)
-                    auto job = KIO::stat(curUrl, KIO::StatJob::DestinationSide, 0);
-#else
                     auto job = KIO::statDetails(url, KIO::StatJob::DestinationSide, KIO::StatDetail::StatBasic);
-#endif
                     KJobWidgets::setWindow(job, parent);
                     fileExists = job->exec();
                 }
@@ -707,6 +699,33 @@ void Util::readGravatarConfig()
     }
 }
 
+QString Util::parseBodyStyle(const QString &style)
+{
+    const int indexStyle = style.indexOf(QLatin1String("style=\""));
+    if (indexStyle != -1) {
+        //qDebug() << " style " << style;
+        const int indexEnd = style.indexOf(QLatin1Char('"'), indexStyle + 7);
+        if (indexEnd != -1) {
+            const QStringRef styleStr = style.midRef(indexStyle + 7, indexEnd - (indexStyle + 7));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+            const auto lstStyle = styleStr.split(QLatin1Char(';'), QString::SkipEmptyParts);
+#else
+            const auto lstStyle = styleStr.split(QLatin1Char(';'), Qt::SkipEmptyParts);
+#endif
+            QStringList lst;
+            for (const auto &style : lstStyle) {
+                if (!style.trimmed().contains(QLatin1String("white-space"))) {
+                    lst.append(style.toString().trimmed());
+                }
+            }
+            if (!lst.isEmpty()) {
+                return QStringLiteral(" style=\"%1").arg(lst.join(QLatin1Char(';'))) + QStringLiteral(";\"");
+            }
+        }
+    }
+    return QString();
+}
+
 // FIXME this used to go through the full webkit parser to extract the body and head blocks
 // until we have that back, at least attempt to fix some of the damage
 // yes, "parsing" HTML with regexps is very very wrong, but it's still better than not filtering
@@ -715,16 +734,23 @@ Util::HtmlMessageInfo Util::processHtml(const QString &htmlSource)
 {
     Util::HtmlMessageInfo messageInfo;
     QString s = htmlSource.trimmed();
-    const int indexDoctype = s.indexOf(QRegExp(QStringLiteral("<!DOCTYPE[^>]*>"), Qt::CaseInsensitive));
+    static QRegularExpression docTypeRegularExpression = QRegularExpression(QStringLiteral("<!DOCTYPE[^>]*>"), QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch matchDocType;
+    const int indexDoctype = s.indexOf(docTypeRegularExpression, 0, &matchDocType);
     QString textBeforeDoctype;
-    if (indexDoctype != -1) {
+    if (indexDoctype > 0) {
         textBeforeDoctype = s.left(indexDoctype);
         s.remove(textBeforeDoctype);
     }
-    s = s.remove(QRegExp(QStringLiteral("^<!DOCTYPE[^>]*>"), Qt::CaseInsensitive)).trimmed();
-    s = s.remove(QRegExp(QStringLiteral("<html[^>]*>"), Qt::CaseInsensitive)).trimmed();
+    const QString capturedString = matchDocType.captured();
+    if (!capturedString.isEmpty()) {
+        s = s.remove(capturedString).trimmed();
+    }
+    static QRegularExpression htmlRegularExpression = QRegularExpression(QStringLiteral("<html[^>]*>"), QRegularExpression::CaseInsensitiveOption);
+    s = s.remove(htmlRegularExpression).trimmed();
     // head
-    s = s.remove(QRegExp(QStringLiteral("^<head/>"), Qt::CaseInsensitive)).trimmed();
+    static QRegularExpression headEndRegularExpression = QRegularExpression(QStringLiteral("^<head/>"), QRegularExpression::CaseInsensitiveOption);
+    s = s.remove(headEndRegularExpression).trimmed();
     const int startIndex = s.indexOf(QLatin1String("<head>"), Qt::CaseInsensitive);
     if (startIndex >= 0) {
         const auto endIndex = s.indexOf(QLatin1String("</head>"), Qt::CaseInsensitive);
@@ -741,17 +767,25 @@ Util::HtmlMessageInfo Util::processHtml(const QString &htmlSource)
         s = s.remove(startIndex, endIndex - startIndex + 7).trimmed();
     }
     // body
-    s = s.remove(QRegExp(QStringLiteral("<body[^>]*>"), Qt::CaseInsensitive)).trimmed();
+    static QRegularExpression body = QRegularExpression(QStringLiteral("<body[^>]*>"), QRegularExpression::CaseInsensitiveOption);
+    QRegularExpressionMatch matchBody;
+    const int bodyStartIndex = s.indexOf(body, 0, &matchBody);
+    if (bodyStartIndex >= 0) {
+        //qDebug() << "matchBody  " << matchBody.capturedTexts();
+        s = s.remove(bodyStartIndex, matchBody.capturedLength()).trimmed();
+        //Parse style
+        messageInfo.bodyStyle = matchBody.captured();
+    }
     //Some mail has </div>$ at end
-    s = s.remove(QRegExp(QStringLiteral("</html></div>$"), Qt::CaseInsensitive)).trimmed();
-    s = s.remove(QRegExp(QStringLiteral("</html>$"), Qt::CaseInsensitive)).trimmed();
-    s = s.remove(QRegExp(QStringLiteral("</body>$"), Qt::CaseInsensitive)).trimmed();
-    s = textBeforeDoctype + s;
-    messageInfo.htmlSource = s;
+    static QRegularExpression htmlDivRegularExpression = QRegularExpression(QStringLiteral("(</html></div>|</html>)$"), QRegularExpression::CaseInsensitiveOption);
+    s = s.remove(htmlDivRegularExpression).trimmed();
+    //s = s.remove(QRegularExpression(QStringLiteral("</html>$"), QRegularExpression::CaseInsensitiveOption)).trimmed();
+    static QRegularExpression bodyEndRegularExpression = QRegularExpression(QStringLiteral("</body>$"), QRegularExpression::CaseInsensitiveOption);
+    s = s.remove(bodyEndRegularExpression).trimmed();
+    messageInfo.htmlSource = textBeforeDoctype + s;
     return messageInfo;
 }
 
-
 QByteArray Util::htmlCodec(const QByteArray &data, const QByteArray &codec)
 {
     QByteArray currentCodec = codec;
@@ -762,11 +796,19 @@ QByteArray Util::htmlCodec(const QByteArray &data, const QByteArray &codec)
         currentCodec = QByteArray("iso-8859-1");
     }
     if (data.contains("charset=\"utf-8\"")
-            || data.contains("charset=\"UTF-8\"")
-            || data.contains("charset=UTF-8")) {
+        || data.contains("charset=\"UTF-8\"")
+        || data.contains("charset=UTF-8")) {
         currentCodec = QByteArray("UTF-8");
     }
 
     //qDebug() << " codec ******************************************: " << codec << " currentCodec : " <<currentCodec;
     return currentCodec;
 }
+
+QDebug operator <<(QDebug d, const Util::HtmlMessageInfo &t)
+{
+    d << " htmlSource " << t.htmlSource;
+    d << " extraHead " << t.extraHead;
+    d << " bodyStyle " << t.bodyStyle;
+    return d;
+}
