@@ -1,23 +1,11 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
-  Copyright (C) 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Copyright (c) 2009 Andras Mantia <andras@kdab.net>
-  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 1997 Markus Wuebben <markus.wuebben@kde.org>
+  SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
+  SPDX-FileCopyrightText: 2009 Andras Mantia <andras@kdab.net>
+  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 // define this to copy all html that is written to the readerwindow to
@@ -41,7 +29,7 @@
 #include <AkonadiCore/itemfetchscope.h>
 #include <QUrl>
 
-#include <mailtransportakonadi/errorattribute.h>
+#include <MailTransportAkonadi/ErrorAttribute>
 
 #include <KLocalizedString>
 
@@ -617,6 +605,12 @@ QAction *Viewer::findInMessageAction() const
     return d->mFindInMessageAction;
 }
 
+QAction *Viewer::shareTextAction() const
+{
+    Q_D(const Viewer);
+    return d->mShareTextAction;
+}
+
 void Viewer::slotChangeDisplayMail(Viewer::DisplayFormatMessage mode, bool loadExternal)
 {
     if ((htmlLoadExtOverride() != loadExternal) || (displayFormatMessageOverwrite() != mode)) {
@@ -638,6 +632,12 @@ QAction *Viewer::resetMessageDisplayFormatAction() const
     return d->mResetMessageDisplayFormat;
 }
 
+QAction *Viewer::developmentToolsAction() const
+{
+    Q_D(const Viewer);
+    return d->mDevelopmentToolsAction;
+}
+
 KToggleAction *Viewer::disableEmoticonAction() const
 {
     Q_D(const Viewer);
@@ -677,7 +677,7 @@ void Viewer::setPluginName(const QString &pluginName)
 void Viewer::showOpenAttachmentFolderWidget(const QList<QUrl> &urls)
 {
     Q_D(Viewer);
-    d->showOpenAttachmentFolderWidget(urls);
+    d->showSavedFileFolderWidget(urls, MessageViewer::OpenSavedFileFolderWidget::FileType::Attachment);
 }
 
 QList<QAction *> Viewer::viewerPluginActionList(ViewerPluginInterface::SpecificFeatureTypes features)
@@ -764,4 +764,11 @@ void Viewer::exportToPdf(const QString &fileName)
     Q_D(Viewer);
     d->exportToPdf(fileName);
 }
+
+void Viewer::showDevelopmentTools()
+{
+    Q_D(Viewer);
+    d->slotShowDevelopmentTools();
+}
+
 }
